@@ -1,12 +1,16 @@
 
 
-#' A dataset abstraction to simplify the calculation of dataset
-#' characteristics.
+#' Dataset abstraction
+#'
+#' Dataset abstraction to simplify characterization.
+#'
 #' @param formula A symbolic description of the dataset
 #' @param data The data frame
 #' @param ordered.as.factor Interpret ordered factors as factors
 #' @param integer.as.numeric Interpret integer variables as numerics
+#'
 #' @return A proto object with an additional S3 class \code{dataset}
+#'
 #' @examples
 #'   data("iris")
 #'   ds <- as.dataset(Species ~ ., iris)
@@ -14,6 +18,9 @@
 #'
 #'   str(ds$response())
 #'   str(ds$dataparts(c("input", "numeric")))
+#'
+#' @family dataset-characterization
+#'
 #' @export
 as.dataset <- function(formula, data, ordered.as.factor = TRUE,
                        integer.as.numeric = TRUE) {
@@ -149,7 +156,7 @@ as.dataset <- function(formula, data, ordered.as.factor = TRUE,
 
     ## Default proto methods:
     pprint <- function(., ...) {
-      cat("Dataset object:\n")
+      cat("Dataset object\n")
       cat(.$dataname(), "-> ")
       print(.$formula())
     }
